/**
 * @file        应用主入口，初始化Elysia实例
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description Elysia API服务应用入口文件
 */

import { Elysia } from 'elysia';
import { swaggerPlugin } from '@/plugins/swagger';
import { authController } from '@/controllers/try/auth.controller';
import { protectedController } from '@/controllers/try/protected.controller';

/**
 * Elysia应用实例
 * @type {Elysia}
 */
export const app = new Elysia()
    .use(swaggerPlugin)
    .use(authController)
    .use(protectedController)
    .state('counter', 0) // 定义名为 counter 的初始值

    // 批量定义  不会覆盖前面单独定义的
    .state({
        version: '1.0',
        server: 'Bun',
    })
    .state('db', '一个方法')
    .decorate('closeDB', () => console.log('关闭方法')); // 添加关闭方法

// 健康检查接口
app.get('/api/health', () => ({
    code: 0,
    message: '服务运行正常',
    data: null,
}));

// app.closeDB() 可以以在路由中调用
