/**
 * @file        JWT认证插件（Elysia官方推荐链式插件）
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description 以Elysia官方链式插件写法实现JWT校验，未通过则返回401
 */

import { Elysia } from 'elysia';
import { jwtPlugin } from './jwt';

export const jwtAuthPlugin = (app: Elysia) =>
    app
        .use(jwtPlugin)
        .derive(async ({ jwt, headers, status }) => {
            const authHeader = headers['authorization'];
            if (!authHeader?.startsWith('Bearer ')) {
                return status(401, {
                    code: 401,
                    message: '未携带Token',
                    data: null,
                });
            }
            const token = authHeader.replace('Bearer ', '');
            try {
                const user = await jwt.verify(token);
                if (!user)
                    return status(401, {
                        code: 401,
                        message: 'Token无效',
                        data: null,
                    });
                console.log('USER', user);
                return { user };
            } catch {
                return {};
            }
        })
        .onBeforeHandle(({ user, set }) => {
            if (!user) {
                set.status = 401;
                return {
                    code: 401 as const,
                    message: '未授权',
                    data: null,
                };
            }
        });
