/**
 * @file        Swagger插件封装
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description 封装Elysia Swagger插件，统一管理API文档配置
 */

import { swagger } from '@elysiajs/swagger';

/**
 * Swagger插件实例
 * @description 统一API文档配置，便于主应用和测试复用
 */
export const swaggerPlugin = swagger({
    documentation: {
        info: {
            title: 'API服务',
            version: '1.0.0',
            description: '基于Elysia的API服务，集成JWT、MySQL等功能',
        },
        components: {
            securitySchemes: {
                bearerAuth: {
                    type: 'http',
                    scheme: 'bearer',
                    bearerFormat: 'JWT',
                    description: 'JWT认证，需在header中携带Authorization: Bearer <token>',
                },
            },
        },
        security: [{ bearerAuth: [] }],
    },
});
