/**
 * @file        受保护接口响应校验规则
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description 受保护接口的响应类型定义，含成功和未授权两种情况
 */

import { t } from 'elysia';
import type { Static } from 'elysia';

/**
 * 受保护接口 200 响应 schema
 */
export const protectedResponse200Schema = t.Object({
    code: t.Literal(0),
    message: t.String(),
    data: t.Object({
        username: t.String(),
        // 可根据实际业务扩展字段
    }),
});

/**
 * 受保护接口 401 响应 schema
 */
export const protectedResponse401Schema = t.Object({
    code: t.Literal(401),
    message: t.String(),
    data: t.Null(),
});

/**
 * 受保护接口 200 响应类型
 */
export type ProtectedResponse200 = Static<typeof protectedResponse200Schema>;

/**
 * 受保护接口 401 响应类型
 */
export type ProtectedResponse401 = Static<typeof protectedResponse401Schema>;
