## 相关文件 (Relevant Files)

- `src/middlewares/logger.ts` - 日志记录中间件，支持分环境、彩色/文件输出、请求id链路追踪。
- `src/middlewares/error-handler.ts` - 全局错误处理中间件，支持分环境详细度。
- `src/utils/response.ts` - 统一响应封装工具函数。
- `src/config/redis.config.ts` - Redis 配置与连接池。
- `src/middlewares/request-id.ts` - 请求id生成与注入中间件。
- `src/routes/health.controller.ts` - 健康检查接口。
- `src/tests/logger.test.ts` - 日志中间件单元测试。
- `src/tests/error-handler.test.ts` - 错误处理中间件单元测试。
- `src/tests/response.test.ts` - 响应封装工具测试。
- `src/tests/redis.test.ts` - Redis 连接与健康检查测试。

### 备注 (Notes)

- 单元测试建议与业务代码分离，统一放在 `src/tests/` 目录。
- 日志文件建议存放在 `logs/` 目录，按天分文件。

## 任务 (Tasks)

- [ ] 1.0 设计与实现日志记录器
  - [ ] 1.1 选型并集成日志库（如 pino/winston/自研）
  - [ ] 1.2 实现分环境日志输出（dev 彩色控制台，prod 文件存储）
  - [ ] 1.3 日志内容包含请求id、method、url、状态码、耗时、IP
  - [ ] 1.4 日志文件按天分割，支持定时清理
  - [ ] 1.5 日志中间件单元测试
- [ ] 2.0 设计与实现全局错误处理器
  - [ ] 2.1 支持自定义业务异常类型
  - [ ] 2.2 dev 环境输出详细堆栈，prod 环境输出友好信息
  - [ ] 2.3 错误日志自动记录
  - [ ] 2.4 错误处理中间件单元测试
- [ ] 3.0 设计与实现统一响应封装
  - [ ] 3.1 封装统一响应结构（code/message/data/traceId/耗时）
  - [ ] 3.2 响应封装工具单元测试
- [ ] 4.0 集成 Redis
  - [ ] 4.1 编写 Redis 配置与连接池
  - [ ] 4.2 实现 Redis 健康检查
  - [ ] 4.3 Redis 相关单元测试
- [ ] 5.0 健康检查接口
  - [ ] 5.1 实现 /health 路由，返回服务与依赖健康状态
- [ ] 6.0 配置中心优化
  - [ ] 6.1 所有配置集中到 config，支持多环境
- [ ] 7.0 Swagger 文档完善
  - [ ] 7.1 增加全局响应示例、错误码说明 